pub struct Error<FactoryError: Fail + Debug, SlaveError: Fail + Debug> {
pub factory: Option<FactoryError>,
pub slave: Option<SlaveError>,
}Expand description
An error when the retry adaptor fails.
It wasn’t possible to log the record (or initialize it when starting). Usually that means it wasn’t possible to create the drain at all or that each newly created drain failed.
Fields
factory: Option<FactoryError>The last error during creation of a new drain, if any.
slave: Option<SlaveError>The last error during logging attempt, if any.